pub struct BoundingBox {
pub min: [f64; 3],
pub max: [f64; 3],
}Expand description
Axis-aligned bounding box (AABB) for 3D geometry.
Fields
min: [f64; 3]Minimum corner.
max: [f64; 3]Maximum corner.
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn new(min: [f64; 3], max: [f64; 3]) -> Self
pub fn new(min: [f64; 3], max: [f64; 3]) -> Self
Create a bounding box from min and max corners.
Sourcepub fn include_point(&mut self, p: [f64; 3])
pub fn include_point(&mut self, p: [f64; 3])
Expand the bounding box to include a point.
Sourcepub fn include_box(&mut self, other: &BoundingBox)
pub fn include_box(&mut self, other: &BoundingBox)
Expand to include another bounding box.
Sourcepub fn from_points(points: &[[f64; 3]]) -> Self
pub fn from_points(points: &[[f64; 3]]) -> Self
Compute from a set of points.
Sourcepub fn surface_area(&self) -> f64
pub fn surface_area(&self) -> f64
Get the surface area.
Sourcepub fn contains_point(&self, p: [f64; 3]) -> bool
pub fn contains_point(&self, p: [f64; 3]) -> bool
Check if a point is inside the bounding box.
Sourcepub fn intersects(&self, other: &BoundingBox) -> bool
pub fn intersects(&self, other: &BoundingBox) -> bool
Check if this box intersects another.
Sourcepub fn convert_units(&self, converter: &UnitConverter) -> BoundingBox
pub fn convert_units(&self, converter: &UnitConverter) -> BoundingBox
Apply a unit conversion to the bounding box.