pub struct CheckpointFileReader {
pub path: PathBuf,
}Expand description
Reads and validates a Checkpoint from a binary file.
Fields
path: PathBufPath to the binary checkpoint file.
Implementations
Sourceimpl CheckpointFileReader
impl CheckpointFileReader
Sourcepub fn read_and_validate(&self) -> Result<Checkpoint>
pub fn read_and_validate(&self) -> Result<Checkpoint>
Read, parse, and validate the checkpoint.
Returns an error if the file cannot be read, the byte format is invalid, or the embedded checksum does not match the state data.