pub struct CheckpointReader {
pub path: PathBuf,
}Expand description
Reads simulation snapshots from a binary checkpoint file.
Fields
path: PathBufSource file path.
Implementations
Sourceimpl CheckpointReader
impl CheckpointReader
Sourcepub fn read_metadata(&self) -> Result<CheckpointMetadata>
pub fn read_metadata(&self) -> Result<CheckpointMetadata>
Read and return the checkpoint metadata from the file header.
Sourcepub fn read_positions(&self) -> Result<Vec<[f64; 3]>>
pub fn read_positions(&self) -> Result<Vec<[f64; 3]>>
Read and return all particle positions stored in the file.