Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

csv_diff
Compute the diff between two CSV tables keyed by key_col.
csv_join
Perform an inner join of left and right on the named key column.
csv_merge
Append all rows of right to left, returning a new table.
csv_pivot
Create a pivot table from table.
infer_column_type
Infer the column type for a slice of string values.
infer_table_types
Infer types for all columns in a CsvTable.