Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

ConfigurableCsvWriter
CSV writer with configurable delimiter, quoting, line endings and precision.
CsvChangedRow
A single changed row in a CsvDiff.
CsvDiff
The result of comparing two CSV datasets.
CsvParser
Full RFC-4180-compliant CSV parser.
CsvReader
Reader for CSV files with numeric data.
CsvRecord
A parsed CSV record (one logical row, possibly spanning multiple physical lines).
CsvStreamParser
A row-at-a-time streaming CSV parser for large files.
CsvTable
An in-memory table of string-valued cells.
CsvWriter
Append-mode CSV writer for time series data.
CsvWriterConfig
Configuration for ConfigurableCsvWriter.
InMemoryCsvReader
In-memory CSV reader that parses a complete CSV string.
InMemoryCsvWriter
In-memory CSV writer with configurable delimiter and floating-point precision.
TypedCsvReader
A CSV reader that exposes per-column typed access after type inference.

Enums

ColumnType
Inferred column type after scanning all values in a column.
PivotAgg
Aggregation function for pivot table values.