parse_smart

Function parse_smart 

pub fn parse_smart(s: &str) -> Result<CsvFile, String>
Parse a CSV string that may or may not have a header row.

If auto_header is true (default behaviour), header presence is inferred using has_header. If no header is detected, synthetic column names col_0, col_1, … are used.