pub fn write_trajectory_csv(frames: &[TrajectoryFrame]) -> StringExpand description
Write a sequence of trajectory frames to a CSV string.
Format: each frame is written as:
# frame_title
x,y,z
x,y,z
...
<blank line>pub fn write_trajectory_csv(frames: &[TrajectoryFrame]) -> StringWrite a sequence of trajectory frames to a CSV string.
Format: each frame is written as:
# frame_title
x,y,z
x,y,z
...
<blank line>