pub struct DatabaseQuery {
pub time_start: Option<f64>,
pub time_end: Option<f64>,
pub name_prefix: Option<String>,
pub param_filter: Option<(String, String)>,
}Expand description
Query predicate for filtering SimulationRecord entries.
Fields
time_start: Option<f64>Keep only records whose timestamp >= this value.
time_end: Option<f64>Keep only records whose timestamp <= this value.
name_prefix: Option<String>Keep only records whose name starts with this prefix.
param_filter: Option<(String, String)>Keep only records that have param key equal to value.
Implementations
Sourceimpl DatabaseQuery
impl DatabaseQuery
Sourcepub fn with_time_range(self, t_start: f64, t_end: f64) -> Self
pub fn with_time_range(self, t_start: f64, t_end: f64) -> Self
Filter by time range [t_start, t_end].
Sourcepub fn with_name_prefix(self, prefix: impl Into<String>) -> Self
pub fn with_name_prefix(self, prefix: impl Into<String>) -> Self
Filter by name prefix.
Sourcepub fn with_param(self, key: impl Into<String>, val: impl Into<String>) -> Self
pub fn with_param(self, key: impl Into<String>, val: impl Into<String>) -> Self
Filter by a parameter key=value match.
Sourcepub fn matches(&self, rec: &SimulationRecord) -> bool
pub fn matches(&self, rec: &SimulationRecord) -> bool
Check whether a SimulationRecord passes this query.