Module fluent_format

Module fluent_format 

ANSYS Fluent mesh format I/O (ASCII .msh).

Supports reading and writing Fluent mesh files containing nodes, faces, cells, and zone assignments. The implementation covers the major section types used in Fluent ASCII mesh files:

  • (0 …) — comment
  • (2 …) — dimension
  • (10 …) — node section
  • (12 …) — cell section
  • (13 …) — face section
  • (45 …) — zone section

Structs

FluentCell
A mesh cell (volume element) in a Fluent mesh.
FluentFace
A mesh face (edge in 2-D, polygon in 3-D) in a Fluent mesh.
FluentMesh
A complete Fluent mesh.
FluentNode
A mesh node (vertex) in a Fluent mesh.
FluentReader
Parses an ANSYS Fluent ASCII .msh file into a FluentMesh.
FluentWriter
Writes a FluentMesh to an ASCII Fluent .msh file.

Enums

FluentCellType
Cell element topology type.
FluentFaceType
Face element topology type.
FluentZoneType
Fluent zone type.