pub struct GeoFeature {
pub id: Option<String>,
pub geometry: Option<GeoGeometry>,
pub properties: Vec<GeoProperty>,
}Expand description
A GeoJSON Feature containing one geometry and a property bag.
Fields
id: Option<String>Optional feature identifier.
geometry: Option<GeoGeometry>The geometry associated with this feature.
properties: Vec<GeoProperty>Key-value properties.
Implementations
Sourceimpl GeoFeature
impl GeoFeature
Sourcepub fn new(geometry: GeoGeometry) -> Self
pub fn new(geometry: GeoGeometry) -> Self
Construct a feature with a geometry and no properties.
Sourcepub fn with_property(
self,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn with_property( self, key: impl Into<String>, value: impl Into<String>, ) -> Self
Add a property and return self for chaining.
Sourcepub fn to_geojson(&self) -> String
pub fn to_geojson(&self) -> String
Serialise this feature to a GeoJSON string.
Sourcepub fn bounding_box(&self) -> Option<BoundingBox>
pub fn bounding_box(&self) -> Option<BoundingBox>
Compute the bounding box of the feature’s geometry.