pub struct CheckpointManager {
pub max_checkpoints: usize,
pub checkpoint_labels: Vec<String>,
}Expand description
Manages a rolling window of checkpoints in a single HDF5 file.
Fields
max_checkpoints: usizeMaximum number of checkpoints to keep.
checkpoint_labels: Vec<String>Labels of currently stored checkpoints (oldest first).
Implementations
Sourceimpl CheckpointManager
impl CheckpointManager
Sourcepub fn write(
&mut self,
file: &mut Hdf5File,
ckpt: &Checkpoint,
) -> Hdf5Result<()>
pub fn write( &mut self, file: &mut Hdf5File, ckpt: &Checkpoint, ) -> Hdf5Result<()>
Write a checkpoint, evicting the oldest if capacity is exceeded.
Sourcepub fn read_latest(&self, file: &Hdf5File) -> Hdf5Result<Checkpoint>
pub fn read_latest(&self, file: &Hdf5File) -> Hdf5Result<Checkpoint>
Read the most recent checkpoint.