pub struct VirtualDataset {
pub shape: Vec<usize>,
pub sources: Vec<(ExternalRef, Hyperslab)>,
pub dtype: Hdf5Dtype,
}Expand description
A virtual dataset that concatenates slices from multiple source files.
Fields
shape: Vec<usize>Final shape of the combined virtual dataset.
sources: Vec<(ExternalRef, Hyperslab)>Sources in order: (external_ref, hyperslab_into_vds).
dtype: Hdf5DtypeDatatype of the virtual dataset.
Implementations
Sourceimpl VirtualDataset
impl VirtualDataset
Sourcepub fn new(shape: Vec<usize>, dtype: Hdf5Dtype) -> Self
pub fn new(shape: Vec<usize>, dtype: Hdf5Dtype) -> Self
Create a new virtual dataset definition.
Sourcepub fn add_source(&mut self, ext_ref: ExternalRef, slab: Hyperslab)
pub fn add_source(&mut self, ext_ref: ExternalRef, slab: Hyperslab)
Add a source contributing to a slice of the virtual dataset.
Sourcepub fn resolve_description(&self) -> String
pub fn resolve_description(&self) -> String
Simulate resolving the virtual dataset (returns a description string).