ChunkingConfig

Struct ChunkingConfig 

pub struct ChunkingConfig {
    pub chunk_dims: Vec<usize>,
}
Chunking configuration for a dataset.

Fields

chunk_dims: Vec<usize>

Chunk dimensions. Must have the same number of dimensions as the dataset.

Implementations

Source

impl ChunkingConfig

pub fn new(chunk_dims: Vec<usize>) -> Self

Create a chunking config with the given chunk dimensions.

pub fn n_chunks(&self, shape: &[usize]) -> usize

Compute the number of chunks needed for a dataset with the given shape.

pub fn chunk_index(&self, element_idx: &[usize], shape: &[usize]) -> usize

Compute the linear index of the chunk containing the given element.

pub fn default_for_shape(shape: &[usize]) -> Self

Default chunking: chunk size of 64 in each dimension.