Tensor

Struct Tensor 

pub struct Tensor {
    pub shape: Vec<usize>,
    pub data: Vec<f64>,
}
A multi-dimensional tensor stored as a flat Vecf64`.

Fields

shape: Vec<usize>

Shape of the tensor (row-major).

data: Vec<f64>

Flat data in row-major order.

Implementations

Source

impl Tensor

pub fn new(shape: Vec<usize>, data: Vec<f64>) -> Self

Construct a tensor with the given shape and flat data.

Panics

Panics if the length of data does not match the product of shape.

pub fn zeros(shape: Vec<usize>) -> Self

Create a zero tensor with the given shape.

pub fn numel(&self) -> usize

Total number of elements.

pub fn ndim(&self) -> usize

Number of dimensions.

pub fn to_bytes(&self) -> Vec<u8>

Serialise to little-endian bytes: \[ndim u64\]\[dim0 u64\]...\[elem f64\]...

pub fn from_bytes(bytes: &[u8]) -> Option<Self>

Deserialise from bytes produced by Tensor::to_bytes.

pub fn add(&self, other: &Tensor) -> Option<Tensor>

Element-wise add (must have identical shape).

pub fn scale(&self, s: f64) -> Tensor

Scalar multiply.

pub fn sum(&self) -> f64

Compute sum of all elements.

pub fn mean(&self) -> f64

Compute mean of all elements.