pub struct Segmentation {
pub labels: Vec<u8>,
pub n_classes: usize,
}Expand description
A voxel-wise segmentation mask aligned to a VoxelVolume.
Fields
labels: Vec<u8>Label for each voxel in the same linear order as the parent volume.
n_classes: usizeNumber of distinct classes (not counting background 0).
Implementations
Sourceimpl Segmentation
impl Segmentation
Sourcepub fn new(n_voxels: usize, n_classes: usize) -> Self
pub fn new(n_voxels: usize, n_classes: usize) -> Self
Create a segmentation mask of n_voxels voxels with n_classes classes.
Sourcepub fn compute_volume(&self, label: u8, spacing: [f64; 3]) -> f64
pub fn compute_volume(&self, label: u8, spacing: [f64; 3]) -> f64
Count voxels with the given label and return the segmented volume in mm³.
spacing is [dx, dy, dz] in mm.
Sourcepub fn label_fraction(&self, label: u8) -> f64
pub fn label_fraction(&self, label: u8) -> f64
Fraction of all voxels assigned to label.