TriangleMesh

Struct TriangleMesh 

pub struct TriangleMesh {
    pub vertices: Vec<[f32; 3]>,
    pub triangles: Vec<[u32; 3]>,
}
A triangle mesh consisting of vertices and triangle connectivity.

Fields

vertices: Vec<[f32; 3]>

3D vertex positions.

triangles: Vec<[u32; 3]>

Triangle face indices (each entry is [v0, v1, v2]).

Implementations

Source

impl TriangleMesh

pub fn new() -> Self

Create an empty mesh.

pub fn from_raw(verts: Vec<[f32; 3]>, tris: Vec<[u32; 3]>) -> Self

Create a mesh from raw vertex and triangle data.

pub fn vertex_count(&self) -> usize

Return the number of vertices.

pub fn triangle_count(&self) -> usize

Return the number of triangles.