pub struct NetcdfWriter { /* private fields */ }Expand description
A builder-style writer for the simplified NetCDF-like text (CDL) format.
Supports dimension management, coordinate variables, typed variables, global attributes, and trajectory serialisation.
Implementations
Sourceimpl NetcdfWriter
impl NetcdfWriter
Sourcepub fn add_dimension(&mut self, name: &str, size: usize) -> &mut Self
pub fn add_dimension(&mut self, name: &str, size: usize) -> &mut Self
Add a fixed-size dimension.
Sourcepub fn add_unlimited_dimension(
&mut self,
name: &str,
current_size: usize,
) -> &mut Self
pub fn add_unlimited_dimension( &mut self, name: &str, current_size: usize, ) -> &mut Self
Add an unlimited (record) dimension.
Sourcepub fn add_global_attribute(&mut self, key: &str, value: &str) -> &mut Self
pub fn add_global_attribute(&mut self, key: &str, value: &str) -> &mut Self
Add a global attribute.
Sourcepub fn add_variable(
&mut self,
name: &str,
dims: &[&str],
data: Vec<f64>,
) -> &mut Self
pub fn add_variable( &mut self, name: &str, dims: &[&str], data: Vec<f64>, ) -> &mut Self
Add a variable with given dimension names and flat data.
Sourcepub fn add_variable_attribute(&mut self, key: &str, value: &str) -> &mut Self
pub fn add_variable_attribute(&mut self, key: &str, value: &str) -> &mut Self
Add an attribute to the most recently added variable.
Sourcepub fn add_coordinate(
&mut self,
dim_name: &str,
data: Vec<f64>,
units: &str,
) -> &mut Self
pub fn add_coordinate( &mut self, dim_name: &str, data: Vec<f64>, units: &str, ) -> &mut Self
Add a coordinate variable (1D variable with the same name as its dimension).
Sourcepub fn n_dimensions(&self) -> usize
pub fn n_dimensions(&self) -> usize
Number of dimensions.
Sourcepub fn n_variables(&self) -> usize
pub fn n_variables(&self) -> usize
Number of variables.
Sourcepub fn write_to_file(&self, path: &str) -> Result<()>
pub fn write_to_file(&self, path: &str) -> Result<()>
Write the CDL to a file.