Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

compute_mesh_stats
Compute mesh statistics for an ObjMesh.
instantiate_mesh
Instantiate mesh with a given transform, returning a new transformed ObjMesh.
merge_obj_meshes
Merge two ObjMesh instances together.
parse_mtl
Parse a Wavefront MTL file content string into a list of materials.
recompute_normals
Recompute per-vertex normals using area-weighted face normals.
weld_vertices
Weld (deduplicate) vertices that are closer than tolerance.