pub fn parse_mtl(data: &str) -> Vec<ObjMaterial>Expand description
Parse a Wavefront MTL file content string into a list of materials.
pub fn parse_mtl(data: &str) -> Vec<ObjMaterial>Parse a Wavefront MTL file content string into a list of materials.