pub struct ObjScene {
pub nodes: Vec<ObjSceneNode>,
pub meshes: Vec<ObjMesh>,
pub materials: Vec<ObjMaterial>,
}Expand description
A simple scene graph for OBJ scenes.
Fields
nodes: Vec<ObjSceneNode>All nodes in the scene.
meshes: Vec<ObjMesh>All meshes in the scene.
materials: Vec<ObjMaterial>All materials in the scene.
Implementations
Sourceimpl ObjScene
impl ObjScene
Sourcepub fn add_mesh(&mut self, mesh: ObjMesh) -> usize
pub fn add_mesh(&mut self, mesh: ObjMesh) -> usize
Add a mesh to the scene and return its index.
Sourcepub fn add_material(&mut self, mat: ObjMaterial) -> usize
pub fn add_material(&mut self, mat: ObjMaterial) -> usize
Add a material to the scene and return its index.
Sourcepub fn add_node(
&mut self,
name: &str,
mesh_index: Option<usize>,
transform: MeshTransform,
) -> usize
pub fn add_node( &mut self, name: &str, mesh_index: Option<usize>, transform: MeshTransform, ) -> usize
Add a node to the scene and return its index.
Sourcepub fn add_child(&mut self, parent_idx: usize, child_idx: usize)
pub fn add_child(&mut self, parent_idx: usize, child_idx: usize)
Set a node as a child of another node.
Sourcepub fn flatten(&self) -> ObjMesh
pub fn flatten(&self) -> ObjMesh
Flatten the scene hierarchy into a single merged ObjMesh.
Each node’s mesh is transformed by the node’s local transform.
Sourcepub fn total_vertices(&self) -> usize
pub fn total_vertices(&self) -> usize
Total number of vertices across all meshes.
Sourcepub fn total_faces(&self) -> usize
pub fn total_faces(&self) -> usize
Total number of faces across all meshes.