pub struct GhostLayer {
pub face: Face,
pub neighbour_rank: usize,
pub depth: usize,
pub tangential_cells: [usize; 2],
}Expand description
Describes the ghost cell layer on a single face.
Fields
face: FaceWhich face this ghost layer belongs to.
neighbour_rank: usizeOwning rank on the other side of this interface.
depth: usizeNumber of ghost cell layers.
tangential_cells: [usize; 2]Number of cells in the two tangential directions [t1, t2].
Implementations