pub struct CameraRobotCalibration {
pub camera_to_robot: Mat4,
pub robot_to_camera: Mat4,
pub intrinsics: CameraIntrinsics,
pub residual_pixels: f64,
pub calibration_date: String,
}Expand description
Camera-to-robot extrinsic calibration (a rigid-body transform).
Fields
camera_to_robot: Mat4Transform from camera frame to robot base frame.
robot_to_camera: Mat4Transform from robot base frame to camera frame.
intrinsics: CameraIntrinsicsCamera intrinsics.
residual_pixels: f64Calibration residual (reprojection error in pixels).
calibration_date: StringCalibration date (ISO 8601 string, informational).
Implementations
Sourceimpl CameraRobotCalibration
impl CameraRobotCalibration
Sourcepub fn identity(intrinsics: CameraIntrinsics) -> Self
pub fn identity(intrinsics: CameraIntrinsics) -> Self
Construct a calibration with identity transform.
Sourcepub fn camera_to_robot_point(&self, p: Vec3) -> Vec3
pub fn camera_to_robot_point(&self, p: Vec3) -> Vec3
Transform a 3-D point from camera frame to robot base frame.
Sourcepub fn robot_to_camera_point(&self, p: Vec3) -> Vec3
pub fn robot_to_camera_point(&self, p: Vec3) -> Vec3
Transform a 3-D point from robot base frame to camera frame.