pub struct PressureTimeSeries {
pub samples: Vec<PressureSample>,
}Expand description
A time-ordered series of pressure samples.
Fields
samples: Vec<PressureSample>The underlying samples.
Implementations
Sourceimpl PressureTimeSeries
impl PressureTimeSeries
Sourcepub fn push(&mut self, s: PressureSample)
pub fn push(&mut self, s: PressureSample)
Append a sample.
Sourcepub fn min_pressure(&self) -> f64
pub fn min_pressure(&self) -> f64
Minimum pressure over the series in Pa, or f64::NAN if empty.
Sourcepub fn max_pressure(&self) -> f64
pub fn max_pressure(&self) -> f64
Maximum pressure over the series in Pa, or f64::NAN if empty.
Sourcepub fn mean_pressure(&self) -> f64
pub fn mean_pressure(&self) -> f64
Mean pressure in Pa.