pub fn sensor_moving_average(
series: &SensorTimeSeries,
window: usize,
) -> SensorTimeSeriesExpand description
Compute a causal moving average of sensor values with the given window size.
The first window-1 values use a partial window.
pub fn sensor_moving_average(
series: &SensorTimeSeries,
window: usize,
) -> SensorTimeSeriesCompute a causal moving average of sensor values with the given window size.
The first window-1 values use a partial window.