EventLog

Struct EventLog 

pub struct EventLog {
    pub events: Vec<LogEvent>,
}
Append-only timestamped event log for a simulation session.

Fields

events: Vec<LogEvent>

All recorded events.

Implementations

Source

impl EventLog

pub fn new() -> Self

Create an empty event log.

pub fn log(&mut self, event: LogEvent)

Append an event.

pub fn info( &mut self, sim_time: f64, category: impl Into<String>, message: impl Into<String>, )

Convenience helper: log a message at Info level.

pub fn warn( &mut self, sim_time: f64, category: impl Into<String>, message: impl Into<String>, )

Convenience helper: log a message at Warning level.

pub fn error( &mut self, sim_time: f64, category: impl Into<String>, message: impl Into<String>, )

Convenience helper: log a message at Error level.

pub fn filter_level(&self, min_level: EventLevel) -> Vec<&LogEvent>

Return all events whose severity is at least min_level.

pub fn filter_category<'a>(&'a self, cat: &str) -> Vec<&'a LogEvent>

Return all events for the given category.

pub fn filter_sim_time(&self, t_lo: f64, t_hi: f64) -> Vec<&LogEvent>

Return all events whose simulation time falls in [t_lo, t_hi].

pub fn to_csv(&self) -> String

Serialize the log to a CSV string.

pub fn len(&self) -> usize

Total number of events recorded.

pub fn is_empty(&self) -> bool

Return true if no events have been logged.