pub struct ProvenanceNode {
pub id: String,
pub type_: ProvenanceType,
pub inputs: Vec<String>,
pub outputs: Vec<String>,
}Expand description
A node in the provenance graph.
Fields
id: StringUnique node identifier.
type_: ProvenanceTypeCategory of this node.
inputs: Vec<String>IDs of nodes that are inputs to this node.
outputs: Vec<String>IDs of nodes that are outputs of this node.
Implementations
Sourceimpl ProvenanceNode
impl ProvenanceNode
Sourcepub fn new(id: impl Into<String>, type_: ProvenanceType) -> Self
pub fn new(id: impl Into<String>, type_: ProvenanceType) -> Self
Create a leaf node with no inputs or outputs.