pub struct ResultAggregator {
pub samples: Vec<f64>,
}Expand description
Aggregates statistics over a collection of snapshots for a named field.
Fields
samples: Vec<f64>Collected scalar samples (one per snapshot time step).
Implementations
Sourceimpl ResultAggregator
impl ResultAggregator
Sourcepub fn add_snapshot_mean(&mut self, snapshot: &Snapshot, field: &str)
pub fn add_snapshot_mean(&mut self, snapshot: &Snapshot, field: &str)
Add the mean value of field from snapshot to the sample set.
Sourcepub fn add_snapshot_max_abs(&mut self, snapshot: &Snapshot, field: &str)
pub fn add_snapshot_max_abs(&mut self, snapshot: &Snapshot, field: &str)
Add the maximum absolute value of field from snapshot.