pub struct TelemetryStream { /* private fields */ }Expand description
Streaming telemetry log that keeps the last capacity entries in memory
while also accumulating all entries for bulk export.
Implementations
Sourceimpl TelemetryStream
impl TelemetryStream
Sourcepub fn push(&mut self, entry: SimLogEntry)
pub fn push(&mut self, entry: SimLogEntry)
Append a new entry to the stream.
Sourcepub fn total_count(&self) -> u64
pub fn total_count(&self) -> u64
Total number of entries ever pushed.
Sourcepub fn ring_iter(&self) -> impl Iterator<Item = &SimLogEntry>
pub fn ring_iter(&self) -> impl Iterator<Item = &SimLogEntry>
Iterate over the entries currently in the ring buffer (may be < capacity).
Sourcepub fn all(&self) -> &[SimLogEntry]
pub fn all(&self) -> &[SimLogEntry]
Return all entries ever pushed.