TecplotZone

Struct TecplotZone 

pub struct TecplotZone {
    pub title: String,
    pub zone_type: TecplotZoneType,
    pub i_dim: usize,
    pub j_dim: usize,
    pub k_dim: usize,
    pub variables: Vec<TecplotVariable>,
    pub n_nodes: usize,
    pub n_elements: usize,
}
A single Tecplot zone containing one or more variables.

Fields

title: String

Zone title string.

zone_type: TecplotZoneType

Zone topology.

i_dim: usize

Number of nodes in the I direction (ordered zones).

j_dim: usize

Number of nodes in the J direction (ordered zones).

k_dim: usize

Number of nodes in the K direction (ordered zones).

variables: Vec<TecplotVariable>

Variable data for this zone.

n_nodes: usize

Number of nodes (FE zones).

n_elements: usize

Number of elements (FE zones).

Implementations

Source

impl TecplotZone

pub fn new_ordered( title: impl Into<String>, i_dim: usize, j_dim: usize, k_dim: usize, ) -> Self

Create a new ordered zone with the given IJK dimensions.

pub fn new_fe( title: impl Into<String>, zone_type: TecplotZoneType, n_nodes: usize, n_elements: usize, ) -> Self

Create a new finite-element zone.

pub fn point_count(&self) -> usize

Total number of data points expected in this zone.