pub struct PvtuWriter;Expand description
Writer for Parallel VTU (.pvtu) header files.
A PVTU file references a set of VTU piece files for parallel I/O.
Implementations
Sourceimpl PvtuWriter
impl PvtuWriter
Sourcepub fn write(
piece_files: &[&str],
point_data_names: &[&str],
cell_data_names: &[&str],
) -> String
pub fn write( piece_files: &[&str], point_data_names: &[&str], cell_data_names: &[&str], ) -> String
Generate a PVTU XML string referencing the given piece files.
point_data_names lists the scalar point data arrays present in each piece.
cell_data_names lists the scalar cell data arrays present in each piece.