VtuFieldOps

Struct VtuFieldOps 

pub struct VtuFieldOps;
Arithmetic operations on VTU scalar fields.

Implementations

Source

impl VtuFieldOps

pub fn add(a: &[f64], b: &[f64]) -> Vec<f64>

Add two fields element-wise, returning the result.

pub fn sub(a: &[f64], b: &[f64]) -> Vec<f64>

Subtract field b from a element-wise.

pub fn mul(a: &[f64], b: &[f64]) -> Vec<f64>

Multiply two fields element-wise.

pub fn scale(a: &[f64], s: f64) -> Vec<f64>

Scale a field by a constant factor.

pub fn vector_magnitude(v: &[f64]) -> Vec<f64>

Compute the L2 norm (magnitude) of a vector field stored as interleaved [x, y, z, x, y, z, …].

pub fn normalize_vectors(v: &[f64]) -> Vec<f64>

Normalize a vector field so each vector has unit length.

pub fn clamp(a: &[f64], lo: f64, hi: f64) -> Vec<f64>

Clamp field values to [lo, hi].

pub fn dot_product(a: &[f64], b: &[f64]) -> Vec<f64>

Compute the dot product of two vector fields (both stored as interleaved XYZ).

pub fn cross_product(a: &[f64], b: &[f64]) -> Vec<f64>

Compute the cross product of two vector fields.

pub fn stats(a: &[f64]) -> (f64, f64, f64)

Compute min, max, mean of a scalar field.

pub fn threshold(a: &[f64], threshold: f64) -> Vec<f64>

Threshold a field: return 1.0 where value > threshold, 0.0 otherwise.