pub struct VtuReader { /* private fields */ }Expand description
Simple reader that extracts point coordinates from a VTU XML string.
Implementations
Sourceimpl VtuReader
impl VtuReader
Sourcepub fn from_xml(data: &str) -> Result<Self>
pub fn from_xml(data: &str) -> Result<Self>
Parse a VTU XML string and extract point coordinates.
Sourcepub fn cell_types(&self) -> &[u8] ⓘ
pub fn cell_types(&self) -> &[u8] ⓘ
Return the cell types parsed from the file.
Sourcepub fn point_data_names(&self) -> &[String]
pub fn point_data_names(&self) -> &[String]
Return point data array names found in the file.
Sourcepub fn cell_data_names(&self) -> &[String]
pub fn cell_data_names(&self) -> &[String]
Return cell data array names found in the file.