pub fn time_average(arr: &XarrayDataArray, time_dim: usize) -> XarrayDataArrayExpand description
Average an array along dimension time_dim.
Returns an array with the same shape except time_dim is reduced to 1.
pub fn time_average(arr: &XarrayDataArray, time_dim: usize) -> XarrayDataArrayAverage an array along dimension time_dim.
Returns an array with the same shape except time_dim is reduced to 1.