write_csv_xarray

Function write_csv_xarray 

pub fn write_csv_xarray(
    dataset: &XarrayDataset,
    path: &str,
) -> Result<(), String>
Write each variable in the dataset as a CSV file.

Each variable is written to path_<variable_name>.csv`. The first line is a header containing the dimension names.