pub fn inner_join_csv(
left: &CsvFile,
right: &CsvFile,
key: &str,
) -> Result<CsvFile, String>Expand description
Inner-join two CsvFiles on a shared key column.
Rows are matched when the key column value is equal (string comparison).
The output contains all columns from left followed by the non-key columns
of right.