pub struct TileId {
pub zoom: u8,
pub x: u32,
pub y: u32,
}Expand description
A Slippy-map tile identifier (zoom / x / y).
Fields
zoom: u8Zoom level (0–22).
x: u32Column tile index.
y: u32Row tile index.
Implementations
Sourceimpl TileId
impl TileId
Sourcepub fn from_lonlat(pt: LonLat, zoom: u8) -> Self
pub fn from_lonlat(pt: LonLat, zoom: u8) -> Self
Compute the TileId that covers a geographic point at a given zoom.
Sourcepub fn bbox(&self) -> BoundingBox
pub fn bbox(&self) -> BoundingBox
Return the bounding box of this tile in geographic coordinates.