pub struct ChunkingConfig {
pub chunk_dims: Vec<usize>,
}Expand description
Chunking configuration for a dataset.
Fields
chunk_dims: Vec<usize>Chunk dimensions. Must have the same number of dimensions as the dataset.
Implementations
Sourceimpl ChunkingConfig
impl ChunkingConfig
Sourcepub fn new(chunk_dims: Vec<usize>) -> Self
pub fn new(chunk_dims: Vec<usize>) -> Self
Create a chunking config with the given chunk dimensions.
Sourcepub fn n_chunks(&self, shape: &[usize]) -> usize
pub fn n_chunks(&self, shape: &[usize]) -> usize
Compute the number of chunks needed for a dataset with the given shape.
Sourcepub fn chunk_index(&self, element_idx: &[usize], shape: &[usize]) -> usize
pub fn chunk_index(&self, element_idx: &[usize], shape: &[usize]) -> usize
Compute the linear index of the chunk containing the given element.
Sourcepub fn default_for_shape(shape: &[usize]) -> Self
pub fn default_for_shape(shape: &[usize]) -> Self
Default chunking: chunk size of 64 in each dimension.