pub struct JsonStreamParser { /* private fields */ }Expand description
A simple streaming JSON parser that processes a JSON array element by element.
Feeds chunks of text and emits complete JSON values as they are parsed.
Implementations
Sourceimpl JsonStreamParser
impl JsonStreamParser
Sourcepub fn feed(&mut self, chunk: &str) -> usize
pub fn feed(&mut self, chunk: &str) -> usize
Feed a chunk of text to the parser. Returns the number of complete values parsed from this chunk.
Sourcepub fn take_results(&mut self) -> Vec<JsonValue>
pub fn take_results(&mut self) -> Vec<JsonValue>
Take all parsed values, leaving the internal store empty.
Sourcepub fn result_count(&self) -> usize
pub fn result_count(&self) -> usize
Number of complete values parsed so far.