pub struct Tensor {
pub shape: Vec<usize>,
pub data: Vec<f64>,
}Expand description
A multi-dimensional tensor stored as a flat Vecf64`.
Fields
shape: Vec<usize>Shape of the tensor (row-major).
data: Vec<f64>Flat data in row-major order.
Implementations
Sourceimpl Tensor
impl Tensor
Sourcepub fn new(shape: Vec<usize>, data: Vec<f64>) -> Self
pub fn new(shape: Vec<usize>, data: Vec<f64>) -> Self
Construct a tensor with the given shape and flat data.
Panics
Panics if the length of data does not match the product of shape.
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Serialise to little-endian bytes: \[ndim u64\]\[dim0 u64\]...\[elem f64\]...
Sourcepub fn from_bytes(bytes: &[u8]) -> Option<Self>
pub fn from_bytes(bytes: &[u8]) -> Option<Self>
Deserialise from bytes produced by Tensor::to_bytes.