pub struct ObjLod {
pub levels: Vec<ObjMesh>,
pub thresholds: Vec<f64>,
}Expand description
A level-of-detail collection: multiple meshes at decreasing resolution.
Fields
levels: Vec<ObjMesh>LOD levels, index 0 = highest detail.
thresholds: Vec<f64>Distance thresholds at which to switch to the next LOD level.
thresholds[i] is the max distance for levels[i].
Implementations
Sourceimpl ObjLod
impl ObjLod
Sourcepub fn push(&mut self, mesh: ObjMesh, threshold: f64)
pub fn push(&mut self, mesh: ObjMesh, threshold: f64)
Add a LOD level with the given switch distance.
Sourcepub fn select(&self, distance: f64) -> Option<&ObjMesh>
pub fn select(&self, distance: f64) -> Option<&ObjMesh>
Select the appropriate LOD level for a viewing distance.
Sourcepub fn num_levels(&self) -> usize
pub fn num_levels(&self) -> usize
Number of LOD levels.
Sourcepub fn decimate(mesh: &ObjMesh, target_faces: usize) -> ObjMesh
pub fn decimate(mesh: &ObjMesh, target_faces: usize) -> ObjMesh
Simplify a mesh to approximately target_faces triangles using
Quadric Error Metric (QEM) edge-collapse.
Implements the Garland–Heckbert (1997) algorithm:
- Compute per-face error quadrics from plane equations.
- Sum quadrics at each vertex.
- For every edge, compute the optimal collapse target position and its associated cost.
- Greedily collapse the minimum-cost edge until
target_facesis reached, using a lazy-deletion min-heap.