pub struct TecplotZone {
pub title: String,
pub zone_type: TecplotZoneType,
pub i_dim: usize,
pub j_dim: usize,
pub k_dim: usize,
pub variables: Vec<TecplotVariable>,
pub n_nodes: usize,
pub n_elements: usize,
}Expand description
A single Tecplot zone containing one or more variables.
Fields
title: StringZone title string.
zone_type: TecplotZoneTypeZone topology.
i_dim: usizeNumber of nodes in the I direction (ordered zones).
j_dim: usizeNumber of nodes in the J direction (ordered zones).
k_dim: usizeNumber of nodes in the K direction (ordered zones).
variables: Vec<TecplotVariable>Variable data for this zone.
n_nodes: usizeNumber of nodes (FE zones).
n_elements: usizeNumber of elements (FE zones).
Implementations
Sourceimpl TecplotZone
impl TecplotZone
Sourcepub fn new_ordered(
title: impl Into<String>,
i_dim: usize,
j_dim: usize,
k_dim: usize,
) -> Self
pub fn new_ordered( title: impl Into<String>, i_dim: usize, j_dim: usize, k_dim: usize, ) -> Self
Create a new ordered zone with the given IJK dimensions.
Sourcepub fn new_fe(
title: impl Into<String>,
zone_type: TecplotZoneType,
n_nodes: usize,
n_elements: usize,
) -> Self
pub fn new_fe( title: impl Into<String>, zone_type: TecplotZoneType, n_nodes: usize, n_elements: usize, ) -> Self
Create a new finite-element zone.
Sourcepub fn point_count(&self) -> usize
pub fn point_count(&self) -> usize
Total number of data points expected in this zone.