pub fn write_csv_xarray(
dataset: &XarrayDataset,
path: &str,
) -> Result<(), String>Expand description
Write each variable in the dataset as a CSV file.
Each variable is written to path_<variable_name>.csv`.
The first line is a header containing the dimension names.